{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Coding Variant filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "--ontology",
                "--filter",
                "Consequence is coding_sequence_variant"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_coding_variant.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.coding_variant_filtered.vcf"
                    },
                    "id": "#filter_vcf_coding_variant.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_coding_variant.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK-3.5.jar",
                "-T",
                "GenotypeGVCFs"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                "-o",
                "genotype.vcf.gz"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--variant"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#gatk_genotypegvcfs.cwl/gvcfs"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_genotypegvcfs.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "genotype.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_genotypegvcfs.cwl/genotype_vcf"
                }
            ],
            "id": "#gatk_genotypegvcfs.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK-3.5.jar",
                "-T",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "${ if (inputs.intervals.length == 1 && inputs.intervals[0].match(/^[0-9A-Za-z]+$/)) { return inputs.intervals[0] + \".g.vcf.gz\"; } else { return \"output.g.vcf.gz\"; } }"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-contamination",
                        "position": 7
                    },
                    "id": "#gatk_haplotypecaller.cwl/contamination_fraction"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-ERC",
                        "position": 3
                    },
                    "id": "#gatk_haplotypecaller.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GQB"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#gatk_haplotypecaller.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#gatk_haplotypecaller.cwl/intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_haplotypecaller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.g.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gvcf"
                }
            ],
            "id": "#gatk_haplotypecaller.cwl"
        },
        {
            "class": "Workflow",
            "label": "scatter GATK HaplotypeCaller over intervals",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/intervals"
                },
                {
                    "type": "string",
                    "id": "#gatk_haplotypecaller_iterator.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                    ],
                    "run": "#gatk_haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/cram",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/cram"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/dbsnp_vcf"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/intervals",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/reference",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller"
                }
            ],
            "id": "#gatk_haplotypecaller_iterator.cwl"
        },
        {
            "class": "Workflow",
            "label": "exome alignment and germline variant detection",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#germline_detect_variants.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#germline_detect_variants.cwl/contamination_fraction"
                },
                {
                    "type": "File",
                    "id": "#germline_detect_variants.cwl/cram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_detect_variants.cwl/custom_gnomad_vcf"
                },
                {
                    "type": "string",
                    "id": "#germline_detect_variants.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#germline_detect_variants.cwl/gvcf_gq_bands"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#germline_detect_variants.cwl/hgvs_annotation"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#germline_detect_variants.cwl/intervals"
                },
                {
                    "type": "File",
                    "id": "#germline_detect_variants.cwl/limit_variant_intervals"
                },
                {
                    "type": "string",
                    "id": "#germline_detect_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#germline_detect_variants.cwl/synonyms_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#germline_detect_variants.cwl/vep_cache_dir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#germline_detect_variants.cwl/index_coding_vcf/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_detect_variants.cwl/coding_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#germline_detect_variants.cwl/index_annotated_vcf/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_detect_variants.cwl/final_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#germline_detect_variants.cwl/haplotype_caller/gvcf",
                    "id": "#germline_detect_variants.cwl/gvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#germline_detect_variants.cwl/limit_variants/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_detect_variants.cwl/limited_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#germline_detect_variants.cwl/annotate_variants/vep_summary",
                    "id": "#germline_detect_variants.cwl/vep_summary"
                }
            ],
            "steps": [
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/vep_cache_dir",
                            "id": "#germline_detect_variants.cwl/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/coding_only",
                            "id": "#germline_detect_variants.cwl/annotate_variants/coding_only"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/custom_gnomad_vcf",
                            "id": "#germline_detect_variants.cwl/annotate_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/hgvs_annotation",
                            "id": "#germline_detect_variants.cwl/annotate_variants/hgvs"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/reference",
                            "id": "#germline_detect_variants.cwl/annotate_variants/reference"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/synonyms_file",
                            "id": "#germline_detect_variants.cwl/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/genotype_gvcfs/genotype_vcf",
                            "id": "#germline_detect_variants.cwl/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/annotate_variants/annotated_vcf",
                        "#germline_detect_variants.cwl/annotate_variants/vep_summary"
                    ],
                    "id": "#germline_detect_variants.cwl/annotate_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/annotate_variants/annotated_vcf",
                            "id": "#germline_detect_variants.cwl/bgzip_annotated_vcf/file"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/bgzip_annotated_vcf/bgzipped_file"
                    ],
                    "id": "#germline_detect_variants.cwl/bgzip_annotated_vcf"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/coding_variant_filter/filtered_vcf",
                            "id": "#germline_detect_variants.cwl/bgzip_coding_vcf/file"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/bgzip_coding_vcf/bgzipped_file"
                    ],
                    "id": "#germline_detect_variants.cwl/bgzip_coding_vcf"
                },
                {
                    "run": "#filter_vcf_coding_variant.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/annotate_variants/annotated_vcf",
                            "id": "#germline_detect_variants.cwl/coding_variant_filter/vcf"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/coding_variant_filter/filtered_vcf"
                    ],
                    "id": "#germline_detect_variants.cwl/coding_variant_filter"
                },
                {
                    "run": "#gatk_genotypegvcfs.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/haplotype_caller/gvcf",
                            "id": "#germline_detect_variants.cwl/genotype_gvcfs/gvcfs"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/reference",
                            "id": "#germline_detect_variants.cwl/genotype_gvcfs/reference"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/genotype_gvcfs/genotype_vcf"
                    ],
                    "id": "#germline_detect_variants.cwl/genotype_gvcfs"
                },
                {
                    "run": "#gatk_haplotypecaller_iterator.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/contamination_fraction",
                            "id": "#germline_detect_variants.cwl/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/cram",
                            "id": "#germline_detect_variants.cwl/haplotype_caller/cram"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/emit_reference_confidence",
                            "id": "#germline_detect_variants.cwl/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/gvcf_gq_bands",
                            "id": "#germline_detect_variants.cwl/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/intervals",
                            "id": "#germline_detect_variants.cwl/haplotype_caller/intervals"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/reference",
                            "id": "#germline_detect_variants.cwl/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/haplotype_caller/gvcf"
                    ],
                    "id": "#germline_detect_variants.cwl/haplotype_caller"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/bgzip_annotated_vcf/bgzipped_file",
                            "id": "#germline_detect_variants.cwl/index_annotated_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/index_annotated_vcf/indexed_vcf"
                    ],
                    "id": "#germline_detect_variants.cwl/index_annotated_vcf"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#germline_detect_variants.cwl/bgzip_coding_vcf/bgzipped_file",
                            "id": "#germline_detect_variants.cwl/index_coding_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/index_coding_vcf/indexed_vcf"
                    ],
                    "id": "#germline_detect_variants.cwl/index_coding_vcf"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#germline_detect_variants.cwl/limit_variants/exclude_filtered"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/limit_variant_intervals",
                            "id": "#germline_detect_variants.cwl/limit_variants/interval_list"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/reference",
                            "id": "#germline_detect_variants.cwl/limit_variants/reference"
                        },
                        {
                            "source": "#germline_detect_variants.cwl/index_coding_vcf/indexed_vcf",
                            "id": "#germline_detect_variants.cwl/limit_variants/vcf"
                        }
                    ],
                    "out": [
                        "#germline_detect_variants.cwl/limit_variants/filtered_vcf"
                    ],
                    "id": "#germline_detect_variants.cwl/limit_variants"
                }
            ],
            "id": "#germline_detect_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "tmpdirMin": 25000
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--plugin",
                "Downstream",
                "--plugin",
                "Wildtype",
                "--symbol",
                "--term",
                "SO",
                "--flag_pick",
                "--transcript_version",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.cache_dir) {\n        return [\"--offline\", \"--cache\", \"--dir\", inputs.cache_dir ]\n    }\n    else {\n        return \"--database\"\n    }\n}\n",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.custom_gnomad_vcf) {\n        return ['--check_existing', '--custom', inputs.custom_gnomad_vcf.path + ',gnomADe,vcf,exact,0,AF,AF_AFR,AF_AMR,AF_ASJ,AF_EAS,AF_FIN,AF_NFE,AF_OTH,AF_SAS']\n    }\n    else {\n        if (inputs.cache_dir) {\n            return ['--max_af', '--af_gnomad', '--af_1kg']\n        }\n        else {\n            return []\n        }\n    }\n}\n",
                        "position": 6
                    },
                    "id": "#vep.cwl/custom_gnomad_vcf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${\n    if (inputs.hgvs) {\n        if (inputs.cache_dir) {\n            return [\"--hgvs\", \"--fasta\", inputs.reference]\n        }\n        else {\n            return [\"--hgvs\"]\n        }\n    }\n    else {\n        return []\n    }\n}\n",
                        "position": 5
                    },
                    "id": "#vep.cwl/hgvs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        },
        {
            "class": "Workflow",
            "label": "wgs alignment and germline variant detection",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/coding_only"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/custom_gnomad_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/gvcf_gq_bands"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/hgvs_annotation"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#main/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/mills"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": "File",
                    "id": "#main/qc_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/readgroups"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": "File",
                    "id": "#main/variant_reporting_intervals"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/vep_cache_dir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/coding_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/coding_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/cram",
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/final_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics",
                    "id": "#main/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics_chart",
                    "id": "#main/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics_summary",
                    "id": "#main/gc_bias_metrics_summary"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/detect_variants/gvcf",
                    "id": "#main/gvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/limited_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/limited_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/mark_duplicates_metrics",
                    "id": "#main/mark_duplicates_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/detect_variants/vep_summary",
                    "id": "#main/vep_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/wgs_metrics",
                    "id": "#main/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#wgs_alignment.cwl",
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/alignment_and_qc/bams"
                        },
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/alignment_and_qc/dbsnp_vcf"
                        },
                        {
                            "source": "#main/qc_intervals",
                            "id": "#main/alignment_and_qc/intervals"
                        },
                        {
                            "source": "#main/known_indels",
                            "id": "#main/alignment_and_qc/known_indels"
                        },
                        {
                            "source": "#main/mills",
                            "id": "#main/alignment_and_qc/mills"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/alignment_and_qc/omni_vcf"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/alignment_and_qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/readgroups",
                            "id": "#main/alignment_and_qc/readgroups"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment_and_qc/reference"
                        }
                    ],
                    "out": [
                        "#main/alignment_and_qc/cram",
                        "#main/alignment_and_qc/mark_duplicates_metrics",
                        "#main/alignment_and_qc/insert_size_metrics",
                        "#main/alignment_and_qc/insert_size_histogram",
                        "#main/alignment_and_qc/alignment_summary_metrics",
                        "#main/alignment_and_qc/gc_bias_metrics",
                        "#main/alignment_and_qc/gc_bias_metrics_chart",
                        "#main/alignment_and_qc/gc_bias_metrics_summary",
                        "#main/alignment_and_qc/wgs_metrics",
                        "#main/alignment_and_qc/flagstats",
                        "#main/alignment_and_qc/verify_bam_id_metrics",
                        "#main/alignment_and_qc/verify_bam_id_depth"
                    ],
                    "id": "#main/alignment_and_qc"
                },
                {
                    "run": "#germline_detect_variants.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/detect_variants/cache_dir"
                        },
                        {
                            "source": "#main/coding_only",
                            "id": "#main/detect_variants/coding_only"
                        },
                        {
                            "source": "#main/extract_freemix/freemix_score",
                            "id": "#main/detect_variants/contamination_fraction"
                        },
                        {
                            "source": "#main/alignment_and_qc/cram",
                            "id": "#main/detect_variants/cram"
                        },
                        {
                            "source": "#main/custom_gnomad_vcf",
                            "id": "#main/detect_variants/custom_gnomad_vcf"
                        },
                        {
                            "source": "#main/emit_reference_confidence",
                            "id": "#main/detect_variants/emit_reference_confidence"
                        },
                        {
                            "source": "#main/gvcf_gq_bands",
                            "id": "#main/detect_variants/gvcf_gq_bands"
                        },
                        {
                            "source": "#main/hgvs_annotation",
                            "id": "#main/detect_variants/hgvs"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/detect_variants/intervals"
                        },
                        {
                            "source": "#main/variant_reporting_intervals",
                            "id": "#main/detect_variants/limit_variant_intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/detect_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/detect_variants/synonyms_file"
                        }
                    ],
                    "out": [
                        "#main/detect_variants/gvcf",
                        "#main/detect_variants/final_vcf",
                        "#main/detect_variants/coding_vcf",
                        "#main/detect_variants/limited_vcf",
                        "#main/detect_variants/vep_summary"
                    ],
                    "id": "#main/detect_variants"
                },
                {
                    "in": [
                        {
                            "source": "#main/alignment_and_qc/verify_bam_id_metrics",
                            "id": "#main/extract_freemix/verify_bam_id_metrics"
                        }
                    ],
                    "out": [
                        "#main/extract_freemix/freemix_score"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "requirements": [
                            {
                                "class": "InlineJavascriptRequirement"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "loadContents": true
                                },
                                "id": "#main/extract_freemix/1cd5ed84-58da-44c7-8658-2a3826fd5b79/verify_bam_id_metrics"
                            }
                        ],
                        "outputs": [
                            {
                                "type": [
                                    "null",
                                    "string"
                                ],
                                "id": "#main/extract_freemix/1cd5ed84-58da-44c7-8658-2a3826fd5b79/freemix_score"
                            }
                        ],
                        "expression": "${\n    var metrics = inputs.verify_bam_id_metrics.contents.split(\"\\n\");\n    if ( metrics[0].split(\"\\t\")[6] == 'FREEMIX' ) {\n        return {'freemix_score': metrics[1].split(\"\\t\")[6]};\n    } else {\n        return {'freemix_score:': null };\n    }\n}\n",
                        "id": "#main/extract_freemix/1cd5ed84-58da-44c7-8658-2a3826fd5b79"
                    },
                    "id": "#main/extract_freemix"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect gc bias metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectGcBiasMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetrics.txt"
                },
                "CHART=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsChart.pdf"
                },
                "S=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsSummary.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_gc_bias_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetrics.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsChart.pdf"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsSummary.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_summary"
                }
            ],
            "id": "#collect_gc_bias_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect WGS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/WgsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_wgs_metrics.cwl/cram"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INTERVALS="
                    },
                    "id": "#collect_wgs_metrics.cwl/intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_wgs_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "WgsMetrics.txt"
                    },
                    "id": "#collect_wgs_metrics.cwl/wgs_metrics"
                }
            ],
            "id": "#collect_wgs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "flagstat.out",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#samtools_flagstat.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "flagstat.out"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        },
        {
            "class": "Workflow",
            "label": "WGS QC workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow_wgs.cwl/cram"
                },
                {
                    "type": "File",
                    "id": "#workflow_wgs.cwl/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow_wgs.cwl/omni_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ALL_READS",
                    "id": "#workflow_wgs.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": "string",
                    "id": "#workflow_wgs.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#workflow_wgs.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/samtools_flagstat/flagstats",
                    "id": "#workflow_wgs.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics",
                    "id": "#workflow_wgs.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_chart",
                    "id": "#workflow_wgs.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_summary",
                    "id": "#workflow_wgs.cwl/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#workflow_wgs.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#workflow_wgs.cwl/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_depth",
                    "id": "#workflow_wgs.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_metrics",
                    "id": "#workflow_wgs.cwl/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow_wgs.cwl/collect_wgs_metrics/wgs_metrics",
                    "id": "#workflow_wgs.cwl/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#workflow_wgs.cwl/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_gc_bias_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_gc_bias_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_wgs.cwl/collect_gc_bias_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_gc_bias_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics",
                        "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_chart",
                        "#workflow_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_summary"
                    ],
                    "id": "#workflow_wgs.cwl/collect_gc_bias_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_insert_size_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#workflow_wgs.cwl/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_metrics",
                        "#workflow_wgs.cwl/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#workflow_wgs.cwl/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_wgs_metrics.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/collect_wgs_metrics/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/intervals",
                            "id": "#workflow_wgs.cwl/collect_wgs_metrics/intervals"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/collect_wgs_metrics/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/collect_wgs_metrics/wgs_metrics"
                    ],
                    "id": "#workflow_wgs.cwl/collect_wgs_metrics"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow_wgs.cwl/reference",
                            "id": "#workflow_wgs.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow_wgs.cwl/cram_to_bam"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram",
                            "id": "#workflow_wgs.cwl/samtools_flagstat/cram"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/samtools_flagstat/flagstats"
                    ],
                    "id": "#workflow_wgs.cwl/samtools_flagstat"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#workflow_wgs.cwl/cram_to_bam/bam",
                            "id": "#workflow_wgs.cwl/verify_bam_id/bam"
                        },
                        {
                            "source": "#workflow_wgs.cwl/omni_vcf",
                            "id": "#workflow_wgs.cwl/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_metrics",
                        "#workflow_wgs.cwl/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#workflow_wgs.cwl/verify_bam_id"
                }
            ],
            "id": "#workflow_wgs.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned to aligned BAM",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#align.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/readgroup"
                },
                {
                    "type": "string",
                    "id": "#align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#align.cwl/align_and_tag/aligned_bam",
                    "id": "#align.cwl/tagged_bam"
                }
            ],
            "steps": [
                {
                    "run": "#align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#align.cwl/bam",
                            "id": "#align.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#align.cwl/readgroup",
                            "id": "#align.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#align.cwl/reference",
                            "id": "#align.cwl/align_and_tag/reference"
                        }
                    ],
                    "out": [
                        "#align.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#align.cwl/align_and_tag"
                }
            ],
            "id": "#align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "position": 4,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#align_and_tag.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#align_and_tag.cwl/readgroup"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#align_and_tag.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "PrintReads"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/Final.bam"
                },
                "-preserveQ",
                "6",
                "-SQQ",
                "10",
                "-SQQ",
                "20",
                "-SQQ",
                "30",
                "-nct",
                "8",
                "--disable_indel_quals"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-BQSR",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "Final.bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "stdout": "final.cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "final.cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                },
                "--preserve_qscores_less_than",
                "6",
                "--disable_auto_index_creation_and_locking_when_reading_rods",
                "--disable_bam_indexing",
                "-dfrac",
                ".1",
                "-nct",
                "4"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-knownSites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "cp",
                "$(inputs.cram.path)",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "ln",
                "-s",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "mark duplicates and sort",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 3,
                    "valueFrom": "$(runtime.outdir)/MarkedSorted.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "MarkedSorted.bam"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "merge BAMs",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "arguments": [
                "AlignedMerged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignedMerged.bam"
                    },
                    "id": "#merge.cwl/merged_bam"
                }
            ],
            "id": "#merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "12G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 13000,
                    "coresMin": 8
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "Workflow",
            "label": "Unaligned BAM to BQSR and VCF",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#workflow.cwl_2/bams"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#workflow.cwl_2/bqsr_intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#workflow.cwl_2/mills"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#workflow.cwl_2/readgroups"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl_2/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/index_cram/indexed_cram",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "id": "#workflow.cwl_2/final_cram"
                },
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl_2/mark_duplicates_and_sort/metrics_file",
                    "id": "#workflow.cwl_2/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#workflow.cwl_2/align/bam",
                        "#workflow.cwl_2/align/readgroup"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#align.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/bams",
                            "id": "#workflow.cwl_2/align/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/readgroups",
                            "id": "#workflow.cwl_2/align/readgroup"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/align/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/align/tagged_bam"
                    ],
                    "id": "#workflow.cwl_2/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_2/apply_bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/bqsr/bqsr_table",
                            "id": "#workflow.cwl_2/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#workflow.cwl_2/apply_bqsr"
                },
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/apply_bqsr/bqsr_bam",
                            "id": "#workflow.cwl_2/bam_to_cram/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/bam_to_cram/cram"
                    ],
                    "id": "#workflow.cwl_2/bam_to_cram"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/mark_duplicates_and_sort/sorted_bam",
                            "id": "#workflow.cwl_2/bqsr/bam"
                        },
                        {
                            "source": "#workflow.cwl_2/bqsr_intervals",
                            "id": "#workflow.cwl_2/bqsr/intervals"
                        },
                        {
                            "source": [
                                "#workflow.cwl_2/dbsnp_vcf",
                                "#workflow.cwl_2/mills",
                                "#workflow.cwl_2/known_indels"
                            ],
                            "id": "#workflow.cwl_2/bqsr/known_sites"
                        },
                        {
                            "source": "#workflow.cwl_2/reference",
                            "id": "#workflow.cwl_2/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/bqsr/bqsr_table"
                    ],
                    "id": "#workflow.cwl_2/bqsr"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/bam_to_cram/cram",
                            "id": "#workflow.cwl_2/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/index_cram/indexed_cram"
                    ],
                    "id": "#workflow.cwl_2/index_cram"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/name_sort/name_sorted_bam",
                            "id": "#workflow.cwl_2/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/mark_duplicates_and_sort/sorted_bam",
                        "#workflow.cwl_2/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#workflow.cwl_2/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/align/tagged_bam",
                            "id": "#workflow.cwl_2/merge/bams"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/merge/merged_bam"
                    ],
                    "id": "#workflow.cwl_2/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl_2/merge/merged_bam",
                            "id": "#workflow.cwl_2/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl_2/name_sort/name_sorted_bam"
                    ],
                    "id": "#workflow.cwl_2/name_sort"
                }
            ],
            "id": "#workflow.cwl_2"
        },
        {
            "class": "Workflow",
            "label": "wgs alignment with qc",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#wgs_alignment.cwl/bams"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/dbsnp_vcf"
                },
                {
                    "type": "File",
                    "id": "#wgs_alignment.cwl/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/known_indels"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/mills"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#wgs_alignment.cwl/omni_vcf"
                },
                {
                    "type": "string",
                    "id": "#wgs_alignment.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#wgs_alignment.cwl/readgroups"
                },
                {
                    "type": "string",
                    "id": "#wgs_alignment.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/alignment_summary_metrics",
                    "id": "#wgs_alignment.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/alignment/final_cram",
                    "id": "#wgs_alignment.cwl/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/flagstats",
                    "id": "#wgs_alignment.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/gc_bias_metrics",
                    "id": "#wgs_alignment.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/gc_bias_metrics_chart",
                    "id": "#wgs_alignment.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/gc_bias_metrics_summary",
                    "id": "#wgs_alignment.cwl/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/insert_size_histogram",
                    "id": "#wgs_alignment.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/insert_size_metrics",
                    "id": "#wgs_alignment.cwl/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/alignment/mark_duplicates_metrics_file",
                    "id": "#wgs_alignment.cwl/mark_duplicates_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/verify_bam_id_depth",
                    "id": "#wgs_alignment.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/verify_bam_id_metrics",
                    "id": "#wgs_alignment.cwl/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#wgs_alignment.cwl/qc/wgs_metrics",
                    "id": "#wgs_alignment.cwl/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#workflow.cwl_2",
                    "in": [
                        {
                            "source": "#wgs_alignment.cwl/bams",
                            "id": "#wgs_alignment.cwl/alignment/bams"
                        },
                        {
                            "source": "#wgs_alignment.cwl/dbsnp_vcf",
                            "id": "#wgs_alignment.cwl/alignment/dbsnp_vcf"
                        },
                        {
                            "source": "#wgs_alignment.cwl/known_indels",
                            "id": "#wgs_alignment.cwl/alignment/known_indels"
                        },
                        {
                            "source": "#wgs_alignment.cwl/mills",
                            "id": "#wgs_alignment.cwl/alignment/mills"
                        },
                        {
                            "source": "#wgs_alignment.cwl/readgroups",
                            "id": "#wgs_alignment.cwl/alignment/readgroups"
                        },
                        {
                            "source": "#wgs_alignment.cwl/reference",
                            "id": "#wgs_alignment.cwl/alignment/reference"
                        }
                    ],
                    "out": [
                        "#wgs_alignment.cwl/alignment/final_cram",
                        "#wgs_alignment.cwl/alignment/mark_duplicates_metrics_file"
                    ],
                    "id": "#wgs_alignment.cwl/alignment"
                },
                {
                    "run": "#workflow_wgs.cwl",
                    "in": [
                        {
                            "source": "#wgs_alignment.cwl/alignment/final_cram",
                            "id": "#wgs_alignment.cwl/qc/cram"
                        },
                        {
                            "source": "#wgs_alignment.cwl/intervals",
                            "id": "#wgs_alignment.cwl/qc/intervals"
                        },
                        {
                            "source": "#wgs_alignment.cwl/omni_vcf",
                            "id": "#wgs_alignment.cwl/qc/omni_vcf"
                        },
                        {
                            "source": "#wgs_alignment.cwl/picard_metric_accumulation_level",
                            "id": "#wgs_alignment.cwl/qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#wgs_alignment.cwl/reference",
                            "id": "#wgs_alignment.cwl/qc/reference"
                        }
                    ],
                    "out": [
                        "#wgs_alignment.cwl/qc/insert_size_metrics",
                        "#wgs_alignment.cwl/qc/insert_size_histogram",
                        "#wgs_alignment.cwl/qc/alignment_summary_metrics",
                        "#wgs_alignment.cwl/qc/gc_bias_metrics",
                        "#wgs_alignment.cwl/qc/gc_bias_metrics_chart",
                        "#wgs_alignment.cwl/qc/gc_bias_metrics_summary",
                        "#wgs_alignment.cwl/qc/wgs_metrics",
                        "#wgs_alignment.cwl/qc/flagstats",
                        "#wgs_alignment.cwl/qc/verify_bam_id_metrics",
                        "#wgs_alignment.cwl/qc/verify_bam_id_depth"
                    ],
                    "id": "#wgs_alignment.cwl/qc"
                }
            ],
            "id": "#wgs_alignment.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
